@@ -1,3 +1,5 @@
+import sys
+
 
 class SimpleCipher:
     CHAR_SET_ODD = ['0', 'o', 'O', '8']
@@ -92,3 +94,66 @@ class SimpleCipher:
             decrypted_message.append(chr(ordinal))
         return ''.join(decrypted_message)
 
+
+class CaesarCipher:
+    def __init__(self):
+        pass
+
+    @staticmethod
+    def encrypt_char(char: str, offset: int = 1) -> str:
+        new_ord = ord(char) + offset
+        if new_ord > sys.maxunicode:
+            new_ord = new_ord % (sys.maxunicode + 1)
+        return chr(new_ord)
+
+    @staticmethod
+    def encrypt(message: str, offset: int = 1) -> str:
+        encrypted_message = []
+        for char in message:
+            encrypted_char = CaesarCipher.encrypt_char(char, offset=offset)
+            encrypted_message.append(encrypted_char)
+        return ''.join(encrypted_message)
+
+    @staticmethod
+    def decrypt_char(char: str, offset: int = 1) -> str:
+        new_ord = ord(char) - offset
+        if new_ord < 0:
+            new_ord += sys.maxunicode + 1
+        return chr(new_ord)
+
+    @staticmethod
+    def decrypt(message: str, offset: int = 1) -> str:
+        decrypted_message = []
+        for char in message:
+            decrypted_char = CaesarCipher.decrypt_char(char, offset=offset)
+            decrypted_message.append(decrypted_char)
+        return ''.join(decrypted_message)
+
+
+class VigenereCipher:
+    VERY_SECRET_KEY = 'cf9acc0a41370810012c03d8a00fbefb'
+
+    def __init__(self):
+        pass
+
+    @staticmethod
+    def crypt(message: str, encrypt: bool = True, key: str = VERY_SECRET_KEY) -> str:
+        crypted_message = []
+        key_length = len(key)
+        for index in range(len(message)):
+            key_ordinal = ord(key[index % key_length])
+            if encrypt:
+                crypted_char = CaesarCipher.encrypt_char(message[index], offset=key_ordinal)
+            else:
+                crypted_char = CaesarCipher.decrypt_char(message[index], offset=key_ordinal)
+            crypted_message.append(crypted_char)
+        return ''.join(crypted_message)
+
+    @staticmethod
+    def encrypt(message: str, key: str = VERY_SECRET_KEY) -> str:
+        return VigenereCipher.crypt(message, encrypt=True, key=key)
+
+    @staticmethod
+    def decrypt(message: str, key: str = VERY_SECRET_KEY) -> str:
+        return VigenereCipher.crypt(message, encrypt=False, key=key)
+            
